import React from 'react';
import PropTypes from 'prop-types';
import clsx from 'clsx';

const baseClasses = 'font-bold py-2 px-4 rounded';
const colorMap = {
    blue: {
        active: 'bg-blue-500 hover:bg-blue-600 text-white',
        disabled: 'bg-blue-500 text-white opacity-50 cursor-not-allowed',
    },
    gray: {
        active: 'bg-gray-700 hover:bg-gray-800 text-white',
        disabled: 'bg-gray-700 text-white opacity-50 cursor-not-allowed',
    },
};

export function NavigationBtn({ type, value, disabled, handleClick, className, color = 'blue' }) {
    const colorClasses = colorMap[color] || colorMap.blue;
    const btnClass = clsx(
        baseClasses,
        disabled ? colorClasses.disabled : colorClasses.active,
        className
    );

    return (
        <button type={type} disabled={disabled} className={btnClass} onClick={handleClick}>
            {value}
        </button>
    );
}

NavigationBtn.propTypes = {
    type: PropTypes.string,
    value: PropTypes.string,
    disabled: PropTypes.bool,
    handleClick: PropTypes.func,
    className: PropTypes.string,
    color: PropTypes.oneOf(['blue', 'gray']),
};

NavigationBtn.defaultProps = {
    type: 'button',
    value: 'Sign in',
    disabled: false,
    handleClick: () => {},
    className: '',
    color: 'blue',
};
