'use client'
import {useContext, useState, useEffect} from 'react';
import {useRouter} from 'next/navigation';
import {AppContext} from '@/context/AppContext';
import {api} from '@/utils';
import {config} from '@/config';
import {useSessionStorage} from '@/hooks';

export function useSsoCallback() {
    const {currentServer, currentVersion} = useContext(AppContext);
    const [isProcessing, setIsProcessing] = useState(false);
    const sessionStore = useSessionStorage();
    const router = useRouter();

    useEffect(() => {
        const url = new URL(window.location.href);
        const code = url.searchParams.get('code');
        const state = url.searchParams.get('state');

        if (!code || !state || !currentServer) return;

        if (state !== sessionStore.storedSsoState) {
            sessionStore.removeSsoState();
            router.push(config.redirectUri);
            return;
        }
        sessionStore.removeSsoState();
        setIsProcessing(true);

        api.post('/api/auth/sso/callback', {
            query: {
                target_server: currentServer,
            },
            body: {
                code,
                redirect_uri: config.redirectUri,
            },
        })
            .then((result) => {
                const { access_token, refresh_token, email } = result;
                sessionStore.storeAccessToken(access_token);
                sessionStore.storeRefreshToken(refresh_token);
                sessionStore.storeUserEmail(email);
                router.push(`/${currentVersion}?target_server=${currentServer}`);
            })
            .catch((err) => {
                console.error('SSO callback failed:', err);
            })
            .finally(() => {
                setIsProcessing(false);
            });
    }, [router, currentServer, currentVersion]);

    return { isProcessing };
}
