import {useState, useEffect, useContext} from 'react';
import {AppContext} from '@/context/AppContext';


export function useFetchClientVersions() {
    const [versions, setVersions] = useState([]);
    const [error, setError] = useState(null);
    const [isLoading, setIsLoading] = useState(false);
    const {setCurrentVersion} = useContext(AppContext);

    useEffect(() => {
        let isMounted = true;
        setIsLoading(true);

        fetch('app/api/available-versions')
            .then((response) => {
                if (!response.ok) {
                    throw new Error('Failed to fetch versions');
                }
                return response.json();
            })
            .then((data) => {
                setVersions(data);
                if (data && Array.isArray(data) && data.length > 0) {
                    setCurrentVersion(data[data.length - 1]?.value);
                }
            })
            .catch((err) => {
                if (isMounted) {
                    setError(err.message);
                }
            })
            .finally(() => {
                if (isMounted) {
                    setIsLoading(false);
                }
            });

        return () => {
            isMounted = false; // Cleanup function to prevent state updates on unmounted component
        };
    }, []);

    return {
        error,
        versions,
        isLoading,
    }
}
