import { promises as fs } from 'fs';

export default async function handler(req, res) {
    try {
        const availableServersFile = await fs.readFile(process.env.AVAILABLE_SERVERS_FILE_PATH, 'utf8');
        const data = JSON.parse(availableServersFile);
        const serversMap = data.servers.reduce((acc, server) => {
            acc[server.hostname] = server;
            return acc;
        }, {});
        const sortedServers = Object.values(serversMap).sort((a, b) => {
            if (a.displayName < b.displayName) return -1;
            if (a.displayName > b.displayName) return 1;
            return 0;
        });

        res.status(200).json(sortedServers);
    } catch (err) {
        console.error(err);
        res.status(500).json({ error: 'Failed to read servers' });
    }
}
