import { promises as fs } from 'fs';

export default async function handler(req, res) {
    try {
        const siteWiseVersionsFile = await fs.readFile(process.env.SITE_WISE_VERSIONS_FILE_PATH, 'utf8');
        const data = JSON.parse(siteWiseVersionsFile);
        const versionsMap = data.versions.reduce((acc, version) => {
            acc[version.value] = version;
            return acc;
        }, {});
        const sortedVersions = Object.values(versionsMap).sort((a, b) => {
            if (a.title < b.title) return -1;
            if (a.title > b.title) return 1;
            return 0;
        });

        res.status(200).json(sortedVersions);
    } catch (err) {
        console.error(err);
        res.status(500).json({ error: 'Failed to read versions' });
    }
}
