const request = async (method, uri, { token, body, headers: customHeaders, query }) => {
    const headers = {
        ...(token && { 'Authorization': `Bearer ${token}` }),
        'Content-Type': 'application/json',
        ...customHeaders,
    };

    const queryString = query
        ? '?' + new URLSearchParams(query).toString()
        : '';

    const res = await fetch(`https://site-wise-portal-dev.rpplabs.com${uri}${queryString}`, {
        method,
        headers,
        body: body ? JSON.stringify(body) : undefined,
    });

    if (!res.ok) {
        if(res.status === 413) {
            const info = 'Content Too Large';
            const error = new Error(info);
            error.info = {message: info};
            error.status = res.status;
            throw error;
        }
        let info;
        try {
            info = await res.json();
        } catch (err) {
            info = {message: await res.text()};
        }

        const error = new Error('An error occurred while fetching the data.');
        error.info = info;
        error.status = res.status;

        throw error;
    }

    return res.json();
};

export const api = {
    get: (uri, options) => request('GET', uri, options),
    post: (uri, options) => request('POST', uri, options),
};
